@@ -1,5 +1,3 @@
-context('tree_distance_path.R')
-
 test_that("path.dist called safely", {
   library("TreeTools")
   expect_equal(c(5.66, 6, 6, 6.32, 6.32, 5.74),
@@ -9,6 +7,7 @@ test_that("path.dist called safely", {
                PathDist(BalancedTree(6), as.phylo(0:5, 6)),
                tolerance = 2)
   
-  expect_equivalent(PathDist(BalancedTree(6), PectinateTree(6)),
-                    PathDist(list(BalancedTree(6), PectinateTree(6)))[1])
+  expect_equal(PathDist(BalancedTree(6), PectinateTree(6)),
+               PathDist(list(BalancedTree(6), PectinateTree(6)))[1],
+               ignore_attr = TRUE)
 })
